@@ -6,18 +6,18 @@ from termcolor import colored
 import f61d.LOGO as LOGO
 
 print(colored(LOGO.randlogo(),choice(['red','yellow','green'])))
-print(colored("Welcome to F61D. Use help() for help.",'green'))
+print(colored("Welcome to F61D. Use Help() for help.",'green'))
 
 help_cont = {}
-help_cont[0] = 'help     : See this help page'
+help_cont[0] = 'Help     : See this help page'
 help_cont[1] = 'fuckstar : One Button to fuck Satellite'
 help_cont[2] = 'lifeGame : Play the Life Game'
 help_cont[3] = 'paint    : Draw a Bing Dwen Dwen'
 help_cont[4] = 'b64tofile: Decode base64 to a file'
 help_cont[5] = 'prove    : Prove your self. Only support:\n                  sha256(XXXX + abcdef) = aaabbb...'
-help_cont[6] = 'nim      : An interesting turtle game.'
+help_cont[6] = 'Nim      : An interesting turtle game.'
 
-def help(page=1,lines = 5):
+def Help(page=1,lines = 5):
     maxPage = int((0.5+len(help_cont))/lines)+1
     if (page - 1) * lines >= len(help_cont):
         print(f'Page Error, check the number : [{1},{maxPage}]')
@@ -83,9 +83,9 @@ please choose mode (1/2):
         ff.write(df)
 
 
-def nim():
-    import f61d.nim
-    nim()
+def Nim():
+    from f61d.nim import game
+    game()
 
 
 def prove(cont):
